chat_ellmer: chat ellmer helper (predates ellmer::chat)
Description
a minimal wrapper function to switch which provider is used for each llm_image* function
when ellmer backend is selected, ollamar only supports ollama
Usage
chat_ellmer(provider = "ollama")
Value
which ellmer function (provider) to use for kuzco llm_image_* when backend is ellmer
Arguments
- provider
a provider, such as "ollama", or "claude", or "github"