Learn R Programming

kuzco (version 0.1.0)

kuzco_app: shiny kuzco app

Description

a simple wrapper of kuzco to make computer vision for everyone. few-shot via frank hull and shiny assistant (https://gallery.shinyapps.io/assistant/)

Usage

kuzco_app()

Arguments

Value

a shiny app instance as a playground for local llms

Examples

Run this code
if (FALSE) {
kuzco_app()
}

Run the code above in your browser using DataLab