# \donttest{
llm_image_custom(
llm_model = "qwen2.5vl",
image = system.file("img/test_img.jpg", package = "kuzco"),
backend = "ellmer",
system_prompt = "You are a terse assistant in computer vision sentiment.",
image_prompt = "return JSON describing image, do not include json or backticks",
example_df = NULL,
provider = "ollama"
)
# }
Run the code above in your browser using DataLab