powered by
a simple wrapper of kuzco to make computer vision for everyone. few-shot via frank hull and shiny assistant (https://gallery.shinyapps.io/assistant/)
kuzco_app()
a shiny app instance as a playground for local llms
if (FALSE) { kuzco_app() }
Run the code above in your browser using DataLab